# Display a model using RobotWrapper {#md_doc_b-examples_display_c-robot-wrapper-viewer}

`RobotWrapper` is a wrapper class written in Python holding Pinocchio models and data.
It also includes wrapper functions for a few common methods.
`RobotWrapper` can interoperate with different visualizers.
Below, you find an example on how to load a model with `RobotWrapper` and how to use it with a visualizer of your choice.

\include robot-wrapper-viewer.py
